@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import hashlib
 from itsdangerous import URLSafeSerializer, SignatureExpired, BadData
 
@@ -16,4 +14,9 @@ def encrypt(string, key):
 def decrypt(token, key):
     salt = _salt(key)    
     s = URLSafeSerializer(key)
-    return s.loads(token, salt=salt)
\ No newline at end of file
+    return s.loads(token, salt=salt)
+
+def hash(s):
+    sha1 = hashlib.sha1()
+    sha1.update(bytearray(s, 'utf-8'))
+    return sha1.hexdigest()
